Fits a linear model and plots fitted values vs residuals to reveal the hidden image embedded by stego_lm_hide.

stego_lm_reveal(data, pch = 16, main = "Residual plot", ...)

Arguments

data

a data.frame produced by stego_lm_hide or stego_lm_hide_text. Must have columns Y, X1, X2, ...

pch

point character, default 16 (filled circle)

main

plot title

...

additional arguments passed to plot

Value

invisible lm object

Examples

if (FALSE) { # \dontrun{
dat <- stego_lm_hide_text("R")
stego_lm_reveal(dat)
} # }